# JoBase

JoBase is a Python library. It is an extention of the Python arcade library. JoBase is aimed at beginner coders - the code is simple and easy to use.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install JoBase.

```bash
pip install JoBase
```

## Get Started

To get started, download the template.py file at [jobase.org](https://jobase.org/). Once you have the file, visit our [tutorials](https://jobase.org/tutorials/) page to begin.

## License

[GNU General Public License v3.0](https://choosealicense.com/licenses/gpl-3.0/)